#!/bin/sh
# usr/opt/wrdapp/tdds/test/test.sh -- run tdds test data sets
#
# Usage: test.sh [start [stop]]
#        test.sh [start [stop]] | tee test.out
#
#        where: start = starting test number
#                stop = ending test number (may be same as start)
#
# To use this script for another program in a different directory, globally
# change the program name (be sure to change both upper and lower case
# occurrences) and set the default value for the Stop variable as appropriate.
#
# History: 12/24/91, mblalock, initial coding
#          04/27/92, mygoze, restructuring
#          01/27/94, rsregan, modified for use with tdds
#
# Variable definitions
# --------------------
#
  TOPDIR=..
  DATA=$TOPDIR/data
  TEST=$TOPDIR/test
  PROG=$TOPDIR/bin/tdds
  CHECK=$TOPDIR/test/check.sh
  CLEAN=$TOPDIR/test/clean.sh
  PROGNM=tdds
  END=2
  DIVD=========================================

  exec 2>&1                                # stderr shows up in .out file

  Start=${1:-1}                            # by default, start at 1
  Stop=${2:-$END}                             # by default, stop at 1
  if [ $Start -lt 1 ] ; then Start=1 ; fi
  if [ $Stop -lt 1 ] ; then Stop=$END ; fi
  if [ $Start -gt $END -o $Stop -gt $END ]
  then
    echo
    echo "Warning, invalid arguments--test range is 1 - $END for $PROGNM"
    echo "input arguments were $Start - $Stop"
    echo
    if [ $Stop -gt $END ] ; then Stop=$END ; fi
    if [ $Start -gt $END ]
    then
      echo "no $PROGNM tests will be performed"
    else
      echo "Tests $Start - $Stop will be performed"
    fi
    echo
  fi

#
# begin test runs
#
  Test=$Start

  if [ $Test -ge $Start -a $Test -le $Stop ]
  then
    echo
    echo $DIVD$DIVD
    echo "Begin processing $PROGNM test runs $Start to $Stop"
    echo
    date
  fi
#
# remove old output file
$CLEAN
#
# Create test data base direct access file, if necessary
  if [ ! -f $DATA/potomac.tdd ]
  then
    cd $DATA
    rm -f TDDB_DSR.MTR backup.rdr
    $PROG < make.tdd
    rm -f TDDB_DSR.MTR backup.rdr backup.prt TDDSLOG.DAT
    cd $TEST
  fi
#
# begin test runs
#
  cp $DATA/tdds1.cfg DIGSPLT1.CFG
  chmod 644 DIGSPLT1.CFG
  while [ $Test -ge $Start -a $Test -le $Stop ]
  do
    echo
    echo
    echo $DIVD$DIVD
    echo "Test run number $Test"
    Name=$PROGNM$Test
    echo "Postscript graphics can be found in "$Name.plt
    $PROG < $DATA/$Name.dat > $Name.log
    mv tdds.plt $Name.plt
    if [ $Test -eq 1 ]
    then
      mv allocate.prt allocate1.prt
      rm TDDB_DSR.MTR
    fi
    Test=`expr $Test + 1`
  done
  Test=`expr $Test - 1`
#
  if [ $Test -ge $Start -a $Test -le $Stop ]
  then
    echo
    echo
    echo $DIVD$DIVD
    echo "Completed $PROGNM test runs $Start to $Test"
    echo
  fi

# check output against original output in $DATA directory
  $CHECK allocate daget dafile daplot xyplot dafix tdds test summary backup
